==> junkutil-1.0.18.zip: src/junkutil/common/FileUtil.java <==
package junkutil.common;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.nio.channels.FileChannel;
import java.util.ArrayList;
import java.util.List;

/**
 * t@C
 * @author Hiroyuki Shiota
 */
public class FileUtil {
	/**
	 * VXẻsR[h
	 */
	public static final String ln = System.getProperty(SystemKey.LINE_SEPARATOR);
	
	/**
	 * vCx[gRXgN^
	 */
	private FileUtil() {
	}
	
	/**
	 * ݂mF
	 * @param filename
	 * @return
	 */
	public static boolean exists(String filename) {
		return new File(filename).exists();
	}
	
	/**
	 * eLXgǂݍ
	 * @param filename - t@C
	 * @return eLXg
	 * @throws IOException
	 */
	public static String readFile(String filename) throws IOException {
		return readFile(filename, null);
	}
	
	/**
	 * eLXgǂݍ
	 * @param filename - t@C
	 * @param encoding - GR[fBO
	 * @return eLXg
	 * @throws IOException
	 */
	public static String readFile(String filename, String encoding) throws IOException {
		BufferedReader br = null;
		StringBuffer result = new StringBuffer();;
		try {
			if (encoding != null) {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename), encoding));
			} else {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename)));
			}
			String line;
			List temp = new ArrayList();
			while ((line = br.readLine()) != null) {
				temp.add(line);
			}
			for (int i = 0; i < temp.size(); i++) {
				result.append((String)temp.get(i));
				if (i+1 < temp.size()) result.append(ln);
			}
		} finally {
			try { br.close(); } catch (Exception ee) {}
		}
		return new String(result);
	}
	
	/**
	 * Ssǂݍ
	 * @param filename - t@C
	 * @return Xg
	 * @throws IOException
	 */
	public static List readLines(String filename) throws IOException {
		return readLines(filename, null);
	}
	
	/**
	 * Ssǂݍ
	 * @param filename - t@C
	 * @return Xg
	 * @throws IOException
	 */
	public static List readLines(String filename, String encoding) throws IOException {
		BufferedReader br = null;
		ArrayList result = null;
		try {
			if (encoding != null) {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename), encoding));
			} else {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename)));
			}
			String line;
			result = new ArrayList();
			while ((line = br.readLine()) != null) {
				result.add(line);
			}
		} finally {
			try { br.close(); } catch (Exception ee) {}
		}
		return result;
	}
	
	/**
	 * sVKɏo
	 * @param filename - t@C
	 * @param list - s
	 */
	public static void writeLines(String filename, List list) throws IOException {
		writeLines(filename, list, null, false);
	}
	
	/**
	 * sVKɏo
	 * @param filename - t@C
	 * @param encoding - GR[fBO
	 * @param list - s
	 */
	public static void writeLines(String filename, List list, String encoding) throws IOException {
		writeLines(filename, list, encoding, false);
	}
	
	/**
	 * sǉŏo
	 * @param filename - t@C
	 * @param list - s
	 */
	public static void appendLines(String filename, List list) throws IOException {
		writeLines(filename, list, null, true);
	}
	
	/**
	 * sǉŏo
	 * @param filename - t@C
	 * @param list - s
	 * @param encoding - GR[fBO
	 */
	public static void appendLines(String filename, List list, String encoding) throws IOException {
		writeLines(filename, list, encoding, true);
	}
	
	/**
	 * t@Co
	 * @param filename - t@C
	 * @param list - s
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeLines(String filename, List list, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			for (int i = 0; i < list.size(); i++) {
				String line = (String)list.get(i);
				bw.write(line);
				bw.newLine();
			}
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); } catch (Exception ee) {}
		}
	}

	/**
	 * eLXgVKɏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @throws IOException
	 */
	public static void writeFile(String filename, String text) throws IOException {
		writeFile(filename, text, null, false);
	}

	/**
	 * eLXgVKɏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void writeFile(String filename, String text, String encoding) throws IOException {
		writeFile(filename, text, encoding, false);
	}

	/**
	 * eLXgǉŏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @throws IOException
	 */
	public static void appendFile(String filename, String text) throws IOException {
		writeFile(filename, text, null, true);
	}
	
	/**
	 * eLXgǉŏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void appendFile(String filename, String text, String encoding) throws IOException {
		writeFile(filename, text, encoding, true);
	}
	
	/**
	 * eLXgo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeFile(String filename, String text, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			bw.write(text);
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); }
			catch (Exception ee) { }
		}
	}

	/**
	 * sVKɈso
	 * @param filename - t@C
	 * @param line - s
	 * @throws IOException
	 */
	public static void writeLine(String filename, String line) throws IOException {
		writeLine(filename, line, null, false);
	}
	
	/**
	 * sVKɈso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void writeLine(String filename, String line, String encoding) throws IOException {
		writeLine(filename, line, encoding, false);
	}
	
	/**
	 * sǉňso
	 * @param filename - t@C
	 * @param line - s
	 * @throws IOException
	 */
	public static void appendLine(String filename, String line) throws IOException {
		writeLine(filename, line, null, true);
	}
	
	/**
	 * sǉňso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void appendLine(String filename, String line, String encoding) throws IOException {
		writeLine(filename, line, encoding, true);
	}
	
	/**
	 * sso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeLine(String filename, String line, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			bw.write(line);
			bw.write(ln);
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); } catch (Exception ee) {}
		}
	}
	
	/**
	 * t@CRs[
	 * @param from
	 * @param to
	 * @throws IOException
	 */
	public static void copy(String from, String to) throws IOException {
		FileChannel fromChanell = new FileInputStream(from).getChannel();
		FileChannel toChannel = new FileOutputStream(to).getChannel();
		try {
			fromChanell.transferTo(0, fromChanell.size(), toChannel);
		} finally {
			fromChanell.close();
			toChannel.close();
		}
	}
	
	/**
	 * oCgzœǂݍ
	 * @param filename
	 * @param buffSize
	 * @return
	 * @throws IOException
	 */
	public static byte[] readByteArray(String filename, int buffSize) throws IOException {
		ByteArrayOutputStream buffer = new ByteArrayOutputStream();
		byte[] buff = new byte[buffSize];
		FileInputStream in = null;
		try {
			in = new FileInputStream(filename);
			int len = 0;
			while ((len = in.read(buff, 0, buff.length)) >= 0) {
				buffer.write(buff, 0, len);
			}
			buffer.flush();
		} finally {
			if (in != null) in.close();
		}
		return buffer.toByteArray();
	}
	
	/**
	 * oCgz
	 * @param filename
	 * @param byteArray
	 * @throws IOException
	 */
	public static void writeByteArray(String filename, byte[] byteArray) throws IOException {
		writeByteArray(filename, byteArray, false);
	}

	/**
	 * oCgzǋL
	 * @param filename
	 * @param byteArray
	 * @throws IOException
	 */
	public static void appendByteArray(String filename, byte[] byteArray) throws IOException {
		writeByteArray(filename, byteArray, true);
	}

	/**
	 * oCgz
	 * @param filename
	 * @param byteArray
	 * @param append
	 * @throws IOException
	 */
	private static void writeByteArray(String filename, byte[] byteArray, boolean append) throws IOException {
		FileOutputStream out = null;
		try {
			out = new FileOutputStream(filename, append);
			out.write(byteArray);
			out.flush();
		} finally {
			if (out != null) out.close();
		}
	}
	
}

==> junkutil-1.0.19.zip: src/junkutil/common/FileUtil.java <==
package junkutil.common;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.nio.channels.FileChannel;
import java.util.ArrayList;
import java.util.List;

/**
 * t@C
 * @author Hiroyuki Shiota
 */
public class FileUtil {
	/**
	 * VXẻsR[h
	 */
	public static final String ln = System.getProperty(SystemKey.LINE_SEPARATOR);

	/**
	 * vCx[gRXgN^
	 */
	private FileUtil() {
	}

	/**
	 * ݂mF
	 * @param filename
	 * @return
	 */
	public static boolean exists(String filename) {
		return new File(filename).exists();
	}

	/**
	 * t@Cgq擾B
	 *
	 * @param str - t@C
	 * @return 擾gq
	 */
	public static String getExtension(String str) {
		int last = -1;
		int start = 0;
		int index = -1;
		while ((index = str.indexOf('\\', start)) != -1) {
			last = index;
			start = index + 1;
		}
		if (last == -1) {
			str = str;
		} else {
			str = str.substring(last + 1);
		}
		last = -1;
		start = 0;
		index = -1;
		while ((index = str.indexOf('.', start)) != -1) {
			last = index;
			start = index + 1;
		}
		if (last == -1) {
			return "";
		} else {
			return str.substring(last + 1);
		}
	}

	/**
	 * eLXgǂݍ
	 * @param filename - t@C
	 * @return eLXg
	 * @throws IOException
	 */
	public static String readFile(String filename) throws IOException {
		return readFile(filename, null);
	}

	/**
	 * eLXgǂݍ
	 * @param filename - t@C
	 * @param encoding - GR[fBO
	 * @return eLXg
	 * @throws IOException
	 */
	public static String readFile(String filename, String encoding) throws IOException {
		BufferedReader br = null;
		StringBuffer result = new StringBuffer();
		try {
			if (encoding != null) {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename), encoding));
			} else {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename)));
			}
			String line;
			List temp = new ArrayList();
			while ((line = br.readLine()) != null) {
				temp.add(line);
			}
			for (int i = 0; i < temp.size(); i++) {
				result.append((String)temp.get(i));
				if (i+1 < temp.size()) result.append(ln);
			}
		} finally {
			try { if (br != null) br.close(); } catch (Exception ee) {}
		}
		return new String(result);
	}

	/**
	 * Ssǂݍ
	 * @param filename - t@C
	 * @return Xg
	 * @throws IOException
	 */
	public static List readLines(String filename) throws IOException {
		return readLines(filename, null);
	}

	/**
	 * Ssǂݍ
	 * @param filename - t@C
	 * @return Xg
	 * @throws IOException
	 */
	public static List readLines(String filename, String encoding) throws IOException {
		BufferedReader br = null;
		ArrayList result = null;
		try {
			if (encoding != null) {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename), encoding));
			} else {
				br = new BufferedReader(new InputStreamReader(new FileInputStream(filename)));
			}
			String line;
			result = new ArrayList();
			while ((line = br.readLine()) != null) {
				result.add(line);
			}
		} finally {
			try { br.close(); } catch (Exception ee) {}
		}
		return result;
	}

	/**
	 * sVKɏo
	 * @param filename - t@C
	 * @param list - s
	 */
	public static void writeLines(String filename, List list) throws IOException {
		writeLines(filename, list, null, false);
	}

	/**
	 * sVKɏo
	 * @param filename - t@C
	 * @param encoding - GR[fBO
	 * @param list - s
	 */
	public static void writeLines(String filename, List list, String encoding) throws IOException {
		writeLines(filename, list, encoding, false);
	}

	/**
	 * sǉŏo
	 * @param filename - t@C
	 * @param list - s
	 */
	public static void appendLines(String filename, List list) throws IOException {
		writeLines(filename, list, null, true);
	}

	/**
	 * sǉŏo
	 * @param filename - t@C
	 * @param list - s
	 * @param encoding - GR[fBO
	 */
	public static void appendLines(String filename, List list, String encoding) throws IOException {
		writeLines(filename, list, encoding, true);
	}

	/**
	 * t@Co
	 * @param filename - t@C
	 * @param list - s
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeLines(String filename, List list, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			for (int i = 0; i < list.size(); i++) {
				String line = (String)list.get(i);
				bw.write(line);
				bw.newLine();
			}
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); } catch (Exception ee) {}
		}
	}

	/**
	 * eLXgVKɏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @throws IOException
	 */
	public static void writeFile(String filename, String text) throws IOException {
		writeFile(filename, text, null, false);
	}

	/**
	 * eLXgVKɏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void writeFile(String filename, String text, String encoding) throws IOException {
		writeFile(filename, text, encoding, false);
	}

	/**
	 * eLXgǉŏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @throws IOException
	 */
	public static void appendFile(String filename, String text) throws IOException {
		writeFile(filename, text, null, true);
	}

	/**
	 * eLXgǉŏo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void appendFile(String filename, String text, String encoding) throws IOException {
		writeFile(filename, text, encoding, true);
	}

	/**
	 * eLXgo
	 * @param filename - t@C
	 * @param text - eLXg
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeFile(String filename, String text, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			bw.write(text);
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); }
			catch (Exception ee) { }
		}
	}

	/**
	 * sVKɈso
	 * @param filename - t@C
	 * @param line - s
	 * @throws IOException
	 */
	public static void writeLine(String filename, String line) throws IOException {
		writeLine(filename, line, null, false);
	}

	/**
	 * sVKɈso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void writeLine(String filename, String line, String encoding) throws IOException {
		writeLine(filename, line, encoding, false);
	}

	/**
	 * sǉňso
	 * @param filename - t@C
	 * @param line - s
	 * @throws IOException
	 */
	public static void appendLine(String filename, String line) throws IOException {
		writeLine(filename, line, null, true);
	}

	/**
	 * sǉňso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @throws IOException
	 */
	public static void appendLine(String filename, String line, String encoding) throws IOException {
		writeLine(filename, line, encoding, true);
	}

	/**
	 * sso
	 * @param filename - t@C
	 * @param line - s
	 * @param encoding - GR[fBO
	 * @param append - ǉtO
	 * @throws IOException
	 */
	private static void writeLine(String filename, String line, String encoding, boolean append) throws IOException {
		BufferedWriter bw = null;
		try {
			if (encoding != null) {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append), encoding));
			} else {
				bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename, append)));
			}
			bw.write(line);
			bw.write(ln);
			bw.flush();
		} finally {
			try { if (bw != null) bw.close(); } catch (Exception ee) {}
		}
	}

	/**
	 * t@CRs[
	 * @param from
	 * @param to
	 * @throws IOException
	 */
	public static void copy(String from, String to) throws IOException {
		FileChannel fromChanell = new FileInputStream(from).getChannel();
		FileChannel toChannel = new FileOutputStream(to).getChannel();
		try {
			fromChanell.transferTo(0, fromChanell.size(), toChannel);
		} finally {
			fromChanell.close();
			toChannel.close();
		}
	}

	/**
	 * oCgzœǂݍ
	 * @param filename
	 * @param buffSize
	 * @return
	 * @throws IOException
	 */
	public static byte[] readByteArray(String filename, int buffSize) throws IOException {
		ByteArrayOutputStream buffer = new ByteArrayOutputStream();
		byte[] buff = new byte[buffSize];
		FileInputStream in = null;
		try {
			in = new FileInputStream(filename);
			int len = 0;
			while ((len = in.read(buff, 0, buff.length)) >= 0) {
				buffer.write(buff, 0, len);
			}
			buffer.flush();
		} finally {
			if (in != null) in.close();
		}
		return buffer.toByteArray();
	}

	/**
	 * oCgz
	 * @param filename
	 * @param byteArray
	 * @throws IOException
	 */
	public static void writeByteArray(String filename, byte[] byteArray) throws IOException {
		writeByteArray(filename, byteArray, false);
	}

	/**
	 * oCgzǋL
	 * @param filename
	 * @param byteArray
	 * @throws IOException
	 */
	public static void appendByteArray(String filename, byte[] byteArray) throws IOException {
		writeByteArray(filename, byteArray, true);
	}

	/**
	 * oCgz
	 * @param filename
	 * @param byteArray
	 * @param append
	 * @throws IOException
	 */
	private static void writeByteArray(String filename, byte[] byteArray, boolean append) throws IOException {
		FileOutputStream out = null;
		try {
			out = new FileOutputStream(filename, append);
			out.write(byteArray);
			out.flush();
		} finally {
			if (out != null) out.close();
		}
	}

}
